Uses of Class
com.google.cloud.dataform.v1beta1.DataformClient.QueryTeamFolderContentsPagedResponse
Packages that use DataformClient.QueryTeamFolderContentsPagedResponse
Package
Description
A client to Dataform API
-
Uses of DataformClient.QueryTeamFolderContentsPagedResponse in com.google.cloud.dataform.v1beta1
Methods in com.google.cloud.dataform.v1beta1 that return DataformClient.QueryTeamFolderContentsPagedResponseModifier and TypeMethodDescriptionDataformClient.queryTeamFolderContents(QueryTeamFolderContentsRequest request) Returns the contents of a given TeamFolder.DataformClient.queryTeamFolderContents(TeamFolderName teamFolder) Returns the contents of a given TeamFolder.DataformClient.queryTeamFolderContents(String teamFolder) Returns the contents of a given TeamFolder.Methods in com.google.cloud.dataform.v1beta1 that return types with arguments of type DataformClient.QueryTeamFolderContentsPagedResponseModifier and TypeMethodDescriptionDataformClient.QueryTeamFolderContentsPagedResponse.createAsync(PageContext<QueryTeamFolderContentsRequest, QueryTeamFolderContentsResponse, QueryTeamFolderContentsResponse.TeamFolderContentsEntry> context, ApiFuture<QueryTeamFolderContentsResponse> futureResponse) final UnaryCallable<QueryTeamFolderContentsRequest,DataformClient.QueryTeamFolderContentsPagedResponse> DataformClient.queryTeamFolderContentsPagedCallable()Returns the contents of a given TeamFolder.PagedCallSettings.Builder<QueryTeamFolderContentsRequest,QueryTeamFolderContentsResponse, DataformClient.QueryTeamFolderContentsPagedResponse> DataformSettings.Builder.queryTeamFolderContentsSettings()Returns the builder for the settings used for calls to queryTeamFolderContents.PagedCallSettings<QueryTeamFolderContentsRequest,QueryTeamFolderContentsResponse, DataformClient.QueryTeamFolderContentsPagedResponse> DataformSettings.queryTeamFolderContentsSettings()Returns the object with the settings used for calls to queryTeamFolderContents. -
Uses of DataformClient.QueryTeamFolderContentsPagedResponse in com.google.cloud.dataform.v1beta1.stub
Methods in com.google.cloud.dataform.v1beta1.stub that return types with arguments of type DataformClient.QueryTeamFolderContentsPagedResponseModifier and TypeMethodDescriptionDataformStub.queryTeamFolderContentsPagedCallable()GrpcDataformStub.queryTeamFolderContentsPagedCallable()HttpJsonDataformStub.queryTeamFolderContentsPagedCallable()PagedCallSettings.Builder<QueryTeamFolderContentsRequest,QueryTeamFolderContentsResponse, DataformClient.QueryTeamFolderContentsPagedResponse> DataformStubSettings.Builder.queryTeamFolderContentsSettings()Returns the builder for the settings used for calls to queryTeamFolderContents.PagedCallSettings<QueryTeamFolderContentsRequest,QueryTeamFolderContentsResponse, DataformClient.QueryTeamFolderContentsPagedResponse> DataformStubSettings.queryTeamFolderContentsSettings()Returns the object with the settings used for calls to queryTeamFolderContents.