Uses of Class
com.google.cloud.dataform.v1beta1.DataformClient.QueryUserRootContentsPagedResponse
Packages that use DataformClient.QueryUserRootContentsPagedResponse
Package
Description
A client to Dataform API
-
Uses of DataformClient.QueryUserRootContentsPagedResponse in com.google.cloud.dataform.v1beta1
Methods in com.google.cloud.dataform.v1beta1 that return DataformClient.QueryUserRootContentsPagedResponseModifier and TypeMethodDescriptionDataformClient.queryUserRootContents(LocationName location) Returns the contents of a caller's root folder in a given location.DataformClient.queryUserRootContents(QueryUserRootContentsRequest request) Returns the contents of a caller's root folder in a given location.DataformClient.queryUserRootContents(String location) Returns the contents of a caller's root folder in a given location.Methods in com.google.cloud.dataform.v1beta1 that return types with arguments of type DataformClient.QueryUserRootContentsPagedResponseModifier and TypeMethodDescriptionDataformClient.QueryUserRootContentsPagedResponse.createAsync(PageContext<QueryUserRootContentsRequest, QueryUserRootContentsResponse, QueryUserRootContentsResponse.RootContentsEntry> context, ApiFuture<QueryUserRootContentsResponse> futureResponse) DataformClient.queryUserRootContentsPagedCallable()Returns the contents of a caller's root folder in a given location.PagedCallSettings.Builder<QueryUserRootContentsRequest,QueryUserRootContentsResponse, DataformClient.QueryUserRootContentsPagedResponse> DataformSettings.Builder.queryUserRootContentsSettings()Returns the builder for the settings used for calls to queryUserRootContents.PagedCallSettings<QueryUserRootContentsRequest,QueryUserRootContentsResponse, DataformClient.QueryUserRootContentsPagedResponse> DataformSettings.queryUserRootContentsSettings()Returns the object with the settings used for calls to queryUserRootContents. -
Uses of DataformClient.QueryUserRootContentsPagedResponse in com.google.cloud.dataform.v1beta1.stub
Methods in com.google.cloud.dataform.v1beta1.stub that return types with arguments of type DataformClient.QueryUserRootContentsPagedResponseModifier and TypeMethodDescriptionDataformStub.queryUserRootContentsPagedCallable()GrpcDataformStub.queryUserRootContentsPagedCallable()HttpJsonDataformStub.queryUserRootContentsPagedCallable()PagedCallSettings.Builder<QueryUserRootContentsRequest,QueryUserRootContentsResponse, DataformClient.QueryUserRootContentsPagedResponse> DataformStubSettings.Builder.queryUserRootContentsSettings()Returns the builder for the settings used for calls to queryUserRootContents.PagedCallSettings<QueryUserRootContentsRequest,QueryUserRootContentsResponse, DataformClient.QueryUserRootContentsPagedResponse> DataformStubSettings.queryUserRootContentsSettings()Returns the object with the settings used for calls to queryUserRootContents.